@@ -9,17 +9,22 @@ enum PIRMakeName{
   Acer_Make,
   Admiral_Make,
   Aiwa_Make,
+  AOC_Make,
   Apple_Make,
+  Arcam_Make,
   Beko_Make,
   Bose_Make,
   Bush_Make,
   Cambridge_Make,
   Canon_Make,
   Daewoo_Make,
+  Dell_Make,
   Denon_Make,
   DigitalStream_Make,
   Directv_Make,
   Dish_Make,
+  DSE_Make,
+  Dynex_Make,
   Ei_Make,
   Elgato_Make,
   Emerson_Make,
@@ -29,6 +34,7 @@ enum PIRMakeName{
   GoldStar_Make,
   Grundig_Make,
   Haier_Make,
+  HarmanKardon_Make,
   Hauppauge_Make,
   Hitachi_Make,
   Homecast_Make,
@@ -37,6 +43,7 @@ enum PIRMakeName{
   Humax_Make,
   Hyundai_Make,
   JVC_Make,
+  Kathrein_Make,
   Kenwood_Make,
   LG_Make,
   Logitech_Make,
@@ -62,6 +69,7 @@ enum PIRMakeName{
   Sharp_Make,
   Sky_Make,
   Sony_Make,
+  Starsat_Make,
   Technics_Make,
   Tivo_Make,
   Topfield_Make,
@@ -69,6 +77,7 @@ enum PIRMakeName{
   United_Make,
   Universum_Make,
   Vestel_Make,
+  Viewsat_Make,
   Virgin_Make,
   Vizio_Make,
   WD_Make,
